<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://www.quanda.com/
 * @since      1.0.0
 *
 * @package    Quanda_Forms
 * @subpackage Quanda_Forms/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Quanda_Forms
 * @subpackage Quanda_Forms/admin
 * @author     Quanda international <kkolis@gmail.com>
 */
class Quanda_Forms_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quanda_Forms_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quanda_Forms_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/quanda-forms-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quanda_Forms_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quanda_Forms_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/quanda-forms-admin.js', array( 'jquery' ), $this->version, false );

	}
	
	/**
	* Register the administration menu for this plugin into the WordPress Dashboard menu.
	*
	* @since    1.0.0
	*/

       public function add_plugin_admin_menu() {

	   /*
	    * Add a settings page for this plugin to the Settings menu.
	    *
	    * NOTE:  Alternative menu locations are available via WordPress administration menu functions.
	    *
	    *        Administration Menus: http://codex.wordpress.org/Administration_Menus
	    *
	    */
	   add_options_page( 'Quanda Forms', 'Quanda Forms', 'manage_options', $this->plugin_name, array($this, 'display_plugin_setup_page')
	   );
       }

	/**
	* Add settings action link to the plugins page.
	*
	* @since    1.0.0
	*/

       public function add_action_links( $links ) {
	   /*
	   *  Documentation : https://codex.wordpress.org/Plugin_API/Filter_Reference/plugin_action_links_(plugin_file_name)
	   */
	  $settings_link = array(
	   '<a href="' . admin_url( 'options-general.php?page=' . $this->plugin_name ) . '">' . __('Settings', $this->plugin_name) . '</a>',
	  );
	  return array_merge(  $settings_link, $links );

       }

       /**
	* Render the settings page for this plugin.
	*
	* @since    1.0.0
	*/

       public function display_plugin_setup_page() {
	   include_once( 'partials/quanda-forms-admin-display.php' );
       }
       
       /**
	*
	* admin/class-wp-cbf-admin.php
	*
	**/
	 public function options_update() {
	    register_setting($this->plugin_name, $this->plugin_name, array($this, 'validate'));
	 }
       
       
       
       /**
	*
	* admin/class-wp-cbf-admin.php
	*
	**/
	public function validate($input) {
	    // All checkboxes inputs        
	    $valid = array();
	    
	    $valid['n1'] = $input['n1'];
	    $valid['r1'] = (isset($input['r1']) && ($input['r1'] === "head")) ? "head" : "specific";
	    $valid['n2'] = $input['n2'];
	    $valid['r2'] = (isset($input['r2']) && ($input['r2'] === "head")) ? "head" : "specific";
	    $valid['n3'] = $input['n3'];
	    $valid['r3'] = (isset($input['r3']) && ($input['r3'] === "head")) ? "head" : "specific";
	    $valid['n4'] = $input['n4'];
	    $valid['r4'] = (isset($input['r4']) && ($input['r4'] === "head")) ? "head" : "specific";
	    $valid['n5'] = $input['n5'];
	    $valid['r5'] = (isset($input['r5']) && ($input['r5'] === "head")) ? "head" : "specific";
	    
	    return $valid;
	 }
	 
	 
	function action_admin_init() {
	 // only hook up these filters if we're in the admin panel, and the current user has permission
	 // to edit posts and pages
	 if ( current_user_can( 'edit_posts' ) && current_user_can( 'edit_pages' ) ) {
	 add_filter( 'mce_buttons', array( $this, 'filter_mce_button' ) );
	 add_filter( 'mce_external_plugins', array( $this, 'filter_mce_plugin' ) );
	 }
	}

	function filter_mce_button( $buttons ) {
	 // add a separation before our button, here our button's id is &quot;mygallery_button&quot;
	 array_push( $buttons, '|', 'mygallery_button' );
	 return $buttons;
	}

	function filter_mce_plugin( $plugins ) {
	 // this plugin file will work the magic of our button
	 $plugins['mygallery'] = plugin_dir_url( __FILE__ ) . 'js/mygallery_plugin.js';
	 return $plugins;
	}


}
