<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://www.quanda.com/
 * @since      1.0.0
 *
 * @package    Quanda_Forms
 * @subpackage Quanda_Forms/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Quanda_Forms
 * @subpackage Quanda_Forms/public
 * @author     Quanda international <kkolis@gmail.com>
 */
class Quanda_Forms_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quanda_Forms_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quanda_Forms_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/quanda-forms-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quanda_Forms_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quanda_Forms_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/quanda-forms-public.js', array( 'jquery' ), $this->version, false );

	}
	
	public function insert_to_header() {
		echo '<script type="text/javascript" src="//webform.onquanda.com/static/js/webform/embedded.min.js"></script>';
  
	}
	
	public function insert_to_footer() {
		$options = get_option($this->plugin_name);
		
		$inputs = array(
		    $options['n1'],
		    $options['n2'],
		    $options['n3'],
		    $options['n4'],
		    $options['n5']
		);
		
		$chbxs = array(
		    $options['r1'],
		    $options['r2'],
		    $options['r3'],
		    $options['r4'],
		    $options['r5'] 
		);
		
		echo "<!-- quanda forms -->";
		foreach ($chbxs as $n => $chb)
		{
			if ($chb === "head")
			{
				echo $inputs[$n]; 
			}
		}
	}
	
	public function register_shortcodes()
	{
		add_shortcode('quanda-form', array( $this,'q_shortcode_helper'));
	}
	
	public function q_shortcode_helper($atts)
	{
		$options = get_option($this->plugin_name);
		
		$inputs = array(
		    "",
		    $options['n1'],
		    $options['n2'],
		    $options['n3'],
		    $options['n4'],
		    $options['n5']
		);
		
		if ($atts['id'] > 0)
		{
			echo $inputs[$atts['id']];
		}
		
	}

}
